Products.GenericSetup — Products.GenericSetup 2.0.2.dev0 documentation

# `Products.GenericSetup`

## Overview

This product provides a mini-framework for expressing the configured state of a Zope Site as a set of filesystem artifacts. These artifacts consist of declarative XML files, which spell out the configuration settings for each “tool” in the site , and supporting scripts / templates, in their “canonical” filesystem representations.

## Configurations Included

The `setup_tool` knows how to export / import configurations and scripts for the following components of a site:

- itself :)

- removal / creation of specified tools

- the role / permission map on the “site” object (its parent)

- properties of the site object

- “Placeful” utilities and adapters registered in the local site manager. Placeless utilities can only be imported.

## Extending The Tool

Third-party products extend the tool by registering handlers for import / export of their unique tools.

See also

See How-to: Writing setup handlers for Products.GenericSetup for a step by step how-to.

## Providing Profiles

GenericSetup doesn’t ship with any profile. They have to be provided by third-party products and depend on the registered handlers.

See also

See About Profiles for more details.

## Other Documentation

- Installing `Products.GenericSetup`
  - Installation via easy_install
  - Installation via `zc.buildout`
  - Manual Installation
- How-to: Writing setup handlers for `Products.GenericSetup`
  - Step 1:
  - Step 2:
  - Step 3:
  - Step 4:
  - Step 5:
  - Step 6:
  - Step 7:
- About Profiles
  - Overview
  - Registering Profiles
  - Update Directives
  - Other Special Directives
- Changelog
  - 2.0.2 (unreleased)
  - 2.0.1 (2019-10-12)
  - 2.0 (2019-05-10)
  - 2.0b6 (2019-04-09)
  - 2.0b5 (2018-12-14)
  - 2.0b4 (2018-11-22)
  - 2.0b3 (2018-11-07)
  - 2.0b2 (2018-10-17)
  - 2.0b1 (2018-05-16)
  - 1.10.0 (2017-12-07)
  - 1.9.1 (2017-05-06)
  - 1.9.0 (2017-05-04)
  - 1.8.7 (2017-03-26)
  - 1.8.6 (2016-12-30)
  - 1.8.5 (2016-11-01)
  - 1.8.4 (2016-09-21)
  - 1.8.3 (2016-04-28)
  - 1.8.2 (2016-02-24)
  - 1.8.1 (2015-12-16)
  - 1.8.0 (2015-09-21)
  - 1.7.7 (2015-08-11)
  - 1.7.6 (2015-07-15)
  - 1.7.5 (2014-10-23)
  - 1.7.4 (2013-06-12)
  - 1.7.3 (2012-10-16)
  - 1.7.2 (2012-07-23)
  - 1.7.1 (2012-02-28)
  - 1.7.0 (2012-01-27)
- Historical Changelog
  - 1.6.8 (2013-01-27)
  - 1.6.7 (2013-01-23)
  - 1.6.6 (2012-02-28)
  - 1.6.5 (2012-01-27)
  - 1.6.4 (2011-10-31)
  - 1.6.3 (2011-04-02)
  - 1.6.2 (2010-08-12)
  - 1.6.1 (2010-07-04)
  - 1.6.0 (2010-03-08)
  - 1.6.0b1 (2010-01-31)
  - 1.5.0 (2010-01-01)
  - 1.5.0b1 (2009-09-25)
  - 1.4.5 (2009-06-20)
  - 1.4.4 (2009-05-15)
  - 1.4.3 (2009-04-22)
  - 1.4.2.2 (2008-09-22)
  - 1.4.2.1 (2008-09-22)
  - 1.4.2 (2008-09-22)
  - 1.4.1 (2008-05-27)
  - 1.4.0 (2008-03-23)
  - 1.4.0-beta (2008-02-07)
  - 1.3.3 (2007-12-29)
  - 1.3.2 (2007-09-11)
  - 1.3.1 (2007-08-08)
  - 1.3 (2007-07-26)
  - 1.3-beta (2007-07-12)
  - 1.2-beta (2006-09-20)
  - 1.1 (2006-04-16)
  - 1.1-beta2 (2006-03-26)
  - 1.1-beta (2006-03-08)
  - 1.0 (2005-09-23)
  - 0.12 (2005-08-29)
  - 0.11 (2005-08-23)
  - 0.10 (2005-08-11)
  - 0.9 (2005-08-08)
- GenericSetup Credits
- Glossary

## Indices and tables

- Index

- Module Index

- Search Page